@@ -17,7 +17,7 @@ import os
 import re
 from elements import *
 import diagparser
-from utils.XY import XY
+from utils import XY
 
 
 class DiagramTreeBuilder:
@@ -115,6 +115,10 @@ class DiagramTreeBuilder:
             elif isinstance(stmt, diagparser.DefAttrs):
                 group.set_attributes(stmt.attrs)
 
+            elif isinstance(stmt, diagparser.AttrClass):
+                name = unquote(stmt.name)
+                Diagram.classes[name] = stmt
+
         group.update_order()
         return group
 
